@@ -1,5 +1,6 @@
 import os
 import pathlib
+import importlib
 
 import numpy as np
 import pytest
@@ -116,15 +117,6 @@ def test_write_file_ana():
     os.remove("ana_test_write.fz")
 
 
-@skip_glymur
-def test_read_file_header_jp2():
-    hlist = sunpy.io.read_file_header(os.path.join(sunpy.data.test.rootdir,
-                                                   "2013_06_24__17_31_30_84__SDO_AIA_AIA_193.jp2"))
-    assert isinstance(hlist, list)
-    assert len(hlist) == 1
-    assert isinstance(hlist[0], sunpy.io.header.FileHeader)
-
-
 @pytest.mark.parametrize('fname', ['aia_171_image.fits',
                                    pathlib.Path('aia_171_image.fits')])
 def test_write_file_fits(fname):
@@ -149,30 +141,6 @@ def test_write_file_fits_bytes():
     os.remove("aia_171_image_bytes.fits")
 
 
-@skip_ana
-def test_read_file_ana():
-    ana_data = sunpy.io.read_file(os.path.join(sunpy.data.test.rootdir, "test_ana.fz"))
-    assert isinstance(ana_data, list)
-    assert len(ana_data) == 1
-    assert len(ana_data[0]) == 2
-    assert isinstance(ana_data[0][0], np.ndarray)
-    assert isinstance(ana_data[0][1], sunpy.io.header.FileHeader)
-
-
-@skip_ana
-def test_read_file__header_ana():
-    ana_data = sunpy.io.read_file_header(os.path.join(sunpy.data.test.rootdir, "test_ana.fz"))
-    assert isinstance(ana_data, list)
-    assert len(ana_data) == 1
-    assert isinstance(ana_data[0], sunpy.io.header.FileHeader)
-
-
-@skip_ana
-def test_write_file_ana():
-    ana = sunpy.io.read_file(os.path.join(sunpy.data.test.rootdir, "test_ana.fz"))[0]
-    sunpy.io.write_file("ana_test_write.fz", ana[0], str(ana[1]))
-    assert os.path.exists("ana_test_write.fz")
-    outpair = sunpy.io.read_file(os.path.join(sunpy.data.test.rootdir, "test_ana.fz"))
-    assert np.all(np.equal(outpair[0][1], ana[1]))
-    assert outpair[0][1] == ana[1]
-    os.remove("ana_test_write.fz")
+def test_old_import():
+    lib = importlib.import_module("sunpy.io.file_tools")
+    assert lib.read_file is sunpy.io.read_file
