@@ -44,8 +44,8 @@ class CDAWEBClient(BaseClient):
     wild2_helio1day_position                              CDAWEB ... Position in heliocentric coordinates from SPDF Helioweb - Natalia Papitashvil...
     >>>
     >>> res = Fido.search(a.Time('2021/07/01', '2021/07/08'),
-    ...                   a.cdaweb.Dataset('SOLO_L2_MAG-RTN-NORMAL-1-MINUTE')) #doctest: +REMOTE_DATA
-    >>> res #doctest: +REMOTE_DATA
+    ...                   a.cdaweb.Dataset('SOLO_L2_MAG-RTN-NORMAL-1-MINUTE')) # doctest: +REMOTE_DATA
+    >>> res # doctest: +REMOTE_DATA
     <sunpy.net.fido_factory.UnifiedResponse object at ...>
     Results from 1 Provider:
     <BLANKLINE>
@@ -152,7 +152,7 @@ class CDAWEBClient(BaseClient):
         from sunpy.net import attrs as a
 
         attrs_path = pathlib.Path(__file__).parent / 'data' / 'attrs.json'
-        with open(attrs_path, 'r') as attrs_file:
+        with open(attrs_path) as attrs_file:
             all_datasets = json.load(attrs_file)
 
         # Convert from dict to list of tuples
